Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4384)

Unified Diff: base/tracked_objects.h

Issue 9181002: Track parent-child relations during profiling (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: base/tracked_objects.h
===================================================================
--- base/tracked_objects.h (revision 119459)
+++ base/tracked_objects.h (working copy)
@@ -442,15 +442,17 @@
// PROFILING_ACTIVE (i.e., it can't be set to a higher level than what is
// compiled into the binary, and parent-child tracking at the
// PROFILING_CHILDREN_ACTIVE level might not be compiled in).
- static bool InitializeAndSetTrackingStatus(bool status);
+ static bool InitializeAndSetTrackingStatus(Status status);
+ static Status status();
+
// Indicate if any sort of profiling is being done (i.e., we are more than
// DEACTIVATED).
- static bool tracking_status();
+ static bool TrackingStatus();
// For testing only, indicate if the status of parent-child tracking is turned
- // on. This is currently a compiled option, atop tracking_status().
- static bool tracking_parent_child_status();
+ // on. This is currently a compiled option, atop TrackingStatus().
+ static bool TrackingParentChildStatus();
// Special versions of Now() for getting times at start and end of a tracked
// run. They are super fast when tracking is disabled, and have some internal

Powered by Google App Engine
This is Rietveld 408576698